package com.ym.mec.education.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.google.common.collect.Lists;
import com.ym.mec.education.base.BaseResponse;
import com.ym.mec.education.base.PageResponse;
import com.ym.mec.education.entity.*;
import com.ym.mec.education.enums.ReturnCodeEnum;
import com.ym.mec.education.mapper.MusicGroupMapper;
import com.ym.mec.education.req.MusicGroupReq;
import com.ym.mec.education.resp.MusicGroupResp;
import com.ym.mec.education.service.*;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * <p>
 * 乐团表 服务实现类
 * </p>
 *
 * @author lemeng
 * @since 2019-09-25
 */
@Service
public class MusicGroupServiceImpl extends ServiceImpl<MusicGroupMapper, MusicGroup> implements IMusicGroupService {

    @Autowired
    private IClassGroupService classGroupService;

    @Autowired
    private IClassGroupTeacherMapperService classGroupTeacherMapperService;

    @Autowired
    private ICourseScheduleTeacherSalaryService courseScheduleTeacherSalaryService;

    @Autowired
    private ITeacherService teacherService;

    @Autowired
    private ISysUserService sysUserService;
    @Override
    public PageResponse groupList(MusicGroupReq req) {
        PageResponse response = new PageResponse();
        IPage page = new Page();
        QueryWrapper<MusicGroup> queryWrapper = new QueryWrapper<>();
        IPage<MusicGroup> queryPage = this.page(page, queryWrapper);
        if (queryPage.getRecords() == null && queryPage.getRecords().isEmpty()) {
            response.setReturnCode(ReturnCodeEnum.CODE_206.getCode());
            return response;
        }

        List<MusicGroup> musicGroupList = queryPage.getRecords();
        List<MusicGroupResp> musicGroupResps = Lists.newArrayList();
        musicGroupList.forEach(g -> {
            MusicGroupResp musicGroupResp = new MusicGroupResp();
            BeanUtils.copyProperties(g, musicGroupResp);
            QueryWrapper<ClassGroup> queryWrapper1 = new QueryWrapper<>();
            queryWrapper1.eq("music_group_id_", g.getId());
            List<ClassGroup> classGroups = classGroupService.list(queryWrapper1);
            if (!CollectionUtils.isEmpty(classGroups)) {
                int studNum = classGroups.stream().mapToInt(ClassGroup::getStudentNum).sum();
                musicGroupResp.setStudentNum(studNum);
            }else{
                musicGroupResp.setStudentNum(0);
            }

            QueryWrapper<ClassGroupTeacherMapper> queryWrapper2 = new QueryWrapper<>();
            queryWrapper2.eq("music_group_id_", g.getId());
            List<ClassGroupTeacherMapper> classGroupTeacherMappers = classGroupTeacherMapperService.list(queryWrapper2);

            if (!CollectionUtils.isEmpty(classGroupTeacherMappers)) {
                int teachNum = classGroupTeacherMappers.size();
                musicGroupResp.setTeacherNum(teachNum);
            }else{
                musicGroupResp.setTeacherNum(0);
            }

            //老师
            SysUser  sysUser1 = sysUserService.getById(g.getTeamTeacherId());

            SysUser  sysUser2 = sysUserService.getById(g.getTeamTeacherId());
            if(sysUser1 != null){
                musicGroupResp.setTeamTeacherName(sysUser1.getUsername());
            }
            if(sysUser2 != null){
                musicGroupResp.setEduTeacherName(sysUser2.getUsername());
            }
            musicGroupResps.add(musicGroupResp);
        });
        int count = this.count(queryWrapper);
        response.setRecords(musicGroupResps);
        response.setReturnCode(ReturnCodeEnum.CODE_200.getCode());
        response.setMessage(ReturnCodeEnum.CODE_200.getValue());
        response.setTotal(count);
        return response;
    }

    @Override
    public BaseResponse groupDetail(Integer groupId) {
        BaseResponse baseResponse = new BaseResponse();

        MusicGroup musicGroup = this.getById(groupId);
        if (musicGroup == null) {
            baseResponse.setReturnCode(ReturnCodeEnum.CODE_207.getCode());
            baseResponse.setMessage(ReturnCodeEnum.CODE_207.getValue());
            return baseResponse;
        }
        MusicGroupResp musicGroupResp = new MusicGroupResp();
        BeanUtils.copyProperties(musicGroup, musicGroupResp);
        QueryWrapper<ClassGroup> queryWrapper1 = new QueryWrapper<>();
        queryWrapper1.eq("music_group_id_", groupId);
        List<ClassGroup> classGroups = classGroupService.list(queryWrapper1);
        if (!CollectionUtils.isEmpty(classGroups)) {
            int studNum = classGroups.stream().mapToInt(ClassGroup::getStudentNum).sum();
            musicGroupResp.setStudentNum(studNum);
        }

        return baseResponse;
    }

    @Override
    public PageResponse classGroupList(Integer groupId) {

        QueryWrapper<ClassGroup> queryWrapper1 = new QueryWrapper<>();
        queryWrapper1.eq("music_group_id_", groupId);
        List<ClassGroup> classGroups = classGroupService.list(queryWrapper1);

        if(!CollectionUtils.isEmpty(classGroups)){
            classGroups.forEach(e ->{
                //查询班级老师
                QueryWrapper<ClassGroupTeacherMapper> queryWrapper2 = new QueryWrapper<>();
                queryWrapper2.eq("music_group_id_",e.getId());
                List<ClassGroupTeacherMapper> list = classGroupTeacherMapperService.list();


            });
        }

        return null;
    }
}
